@@ -85,20 +85,14 @@ def main():
 def hashivault_k8s_auth_role(module):
     params = module.params
     client = hashivault_auth_client(params)
-    mount_point = params.get('mount_point')
+    mount_point = params.get('mount_point').strip('/')
     role_file = params.get('role_file')
-    name = params.get('name')
+    name = params.get('name').strip('/')
     state = params.get('state')
     desired_state = dict()
     exists = False
     changed = False
 
-    # do not want a trailing slash in name
-    if name[-1] == '/':
-        name = name.strip('/')
-    if mount_point[-1]:
-        mount_point = mount_point.strip('/')
-
     if role_file:
         desired_state = json.loads(open(params.get('role_file'), 'r').read())
     else:
@@ -111,7 +105,9 @@ def hashivault_k8s_auth_role(module):
 
     # check if engine is enabled
     try:
-        if (mount_point + "/") not in client.sys.list_auth_methods():
+        result = client.sys.list_auth_methods()
+        backends = result.get('data', result)
+        if (mount_point + "/") not in backends:
             return {'failed': True, 'msg': 'auth method is not enabled', 'rc': 1}
     except:
         if module.check_mode:
